pitchtools.IntervalClassVector
==============================

.. abjad-lineage:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector

.. autoclass:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.clear
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.copy
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.elements
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.from_selection
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.item_class
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.items
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.keys
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.most_common
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.subtract
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.update
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.values
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.viewitems
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.viewkeys
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.viewvalues
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__add__
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__and__
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__contains__
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__delitem__
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__eq__
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__format__
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__getitem__
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__hash__
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__iter__
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__len__
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__missing__
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__ne__
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__or__
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__repr__
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__setitem__
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__str__
      ~abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__sub__

Bases
-----

- :py:class:`pitchtools.Vector <abjad.tools.pitchtools.Vector.Vector>`

- :py:class:`datastructuretools.TypedCounter <abjad.tools.datastructuretools.TypedCounter.TypedCounter>`

- :py:class:`datastructuretools.TypedCollection <abjad.tools.datastructuretools.TypedCollection.TypedCollection>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.item_class
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.clear
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.copy
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.elements
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.items
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.keys
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.most_common
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.subtract
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.update
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.values
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.viewitems
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.viewkeys
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.viewvalues
   :noindex:

Class methods
-------------

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.from_selection
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__add__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__and__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__contains__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__delitem__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__format__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__getitem__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__iter__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__len__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__missing__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__or__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__setitem__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__str__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassVector.IntervalClassVector.__sub__
   :noindex:
